diff --git a/src/lib/components/PlayerControls.svelte b/src/lib/components/PlayerControls.svelte
index 906d94b..a3b2ac2 100644
--- a/src/lib/components/PlayerControls.svelte
+++ b/src/lib/components/PlayerControls.svelte
@@ -127,11 +127,12 @@
onOpenCaptionSettings();
}
// Sync PiP/fullscreen state periodically
$effect(() => {
const interval = setInterval(() => {
pipActive = isPiPActive();
fullscreenActive = isFullscreenActive();
+ currentRate = getPlaybackRate();
}, 500);
return () => clearInterval(interval);
});
@@ -149,56 +150,10 @@
aria-label="Player controls"
>
-
-
-
- {#if hoverTime !== null}
-
- {formatTime(hoverTime)}
-
- {/if}
-
-
-
+
-
+
-
-
-
-
-
-
+
-
- {formatTime(session.currentTime)}
- /
- {formatTime(session.duration)}
-
+
+
+
@@ -232,7 +200,7 @@
@@ -273,15 +241,47 @@
>{fullscreenActive ? '⤓' : '⛶'}
+
+
+
+
+ {#if hoverTime !== null}
+
+ {formatTime(hoverTime)}
+
+ {/if}
+
+
+
+
+ {formatTime(session.currentTime)}
+ {formatTime(session.duration)}
+
@@ -127,11 +127,12 @@
onOpenCaptionSettings();
}
- // Sync PiP/fullscreen state periodically
+ // Sync PiP/fullscreen/rate state periodically
$effect(() => {
const interval = setInterval(() => {